

# Janis - Core


![GitHub stars](https://img.shields.io/github/stars/PMCC-BioinformaticsCore/janis.svg?style=social)  [![Build Status](https://travis-ci.org/PMCC-BioinformaticsCore/janis-core.svg?branch=master)](https://travis-ci.org/PMCC-BioinformaticsCore/janis-core)  [![Documentation Status](https://readthedocs.org/projects/janis/badge/?version=latest)](https://janis.readthedocs.io/en/latest/?badge=latest)  [![PyPI version](https://badge.fury.io/py/janis-pipelines.core.svg)](https://badge.fury.io/py/janis-pipelines.core)  [![codecov](https://codecov.io/gh/PMCC-BioinformaticsCore/janis-core/branch/master/graph/badge.svg)](https://codecov.io/gh/PMCC-BioinformaticsCore/janis-core) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
  
  
_Janis is a framework creating specialised, simple workflow definitions that are then transpiled to   
Common Workflow Language or Workflow Definition Language._  

- The main repository can be found here: https://github.com/PMCC-BioinformaticsCore/janis
- Documentation is hosted here: https://janis.readthedocs.io/  
  
---

This repository declares the core workflow classes for Janis. 